<?php 

/**
  * @file
  * Handles the file processes and html parsing for exporting a Drupal node.
  * Returns a FTP connection, export path, and exportable item to the main module
  */

function savetoftp_create_directories($everything) {
  $folders = array();
  $export_folder = '/savetoftp';
  $export_path = $_SERVER['DOCUMENT_ROOT'] . base_path() . file_directory_path() . $export_folder;
  if (!is_dir($export_path)) {
    mkdir($export_path);
  }
  if ($everything) {
    $misc_directory = $export_path .'/misc';
    $folders[] = 'misc';
    if (!is_dir($misc_directory)) {
      if (!mkdir($misc_directory, 0777, TRUE)) {
    drupal_set_message('unable to make '. $misc_directory);
  }
    }
    $theme_directory = $export_path .'/'. path_to_theme();
    $folders[] = path_to_theme();
    if (!is_dir($theme_directory)) {
      if (!mkdir($theme_directory, 0777, TRUE)) {
    drupal_set_message('unable to make '. $theme_directory);
  }
    }
    $modules = module_list();
    foreach ($modules as $module) {
      $module_directory = $export_path .'/'. drupal_get_path('module', $module);
      $folders[] = drupal_get_path('module', $module);
      if (!is_dir($module_directory)) {
        if (!mkdir($module_directory, 0777, TRUE)) {
    drupal_set_message('unable to make '. $module_directory);
  }
      }
    }
    $new_folders = copy_all_css_js_images($folders, $export_path, $export_folder);
    copy_all_css_js_images($new_folders, $export_path, $export_folder); 
  }
}
 
function copy_all_css_js_images($folders, $export_path, $export_folder) {
  $path =  realpath($_SERVER['DOCUMENT_ROOT'] . base_path());
  $file_types = array('css', 'js', 'png', 'jpg', 'gif');
  foreach ($folders as $folder) {
    $full_path = realpath($path .'/'. $folder);
      $dir_entries = new RecursiveDirectoryIterator($full_path);
    while ($dir_entries->valid()) {
      if (!$dir_entries->isDot()) {
        $dir_entries_path = realpath($dir_entries->key());
        if ($dir_entries->getType() != 'file') {
          $dirs_to_copy = $export_path . str_replace($path, '', $dir_entries_path);
          $new_folders[] .= str_replace($export_path, '', $dirs_to_copy);
          if (!is_dir($dirs_to_copy)) {
            mkdir($dirs_to_copy, 0777, TRUE);
          }
        }
        if ($dir_entries->isFile()) {
          $file_type = end(explode('.', $dir_entries->getFilename()));
          if (in_array($file_type, $file_types)) {  
            $file_to_path = realpath($export_path) . str_replace(realpath($_SERVER['DOCUMENT_ROOT'] . base_path()), '', $dir_entries->getPathname());  
            file_copy($dir_entries->getPathname(), $file_to_path, FILE_EXISTS_REPLACE); 
          }     
        }
      }
    $dir_entries->next();
    }
  }  
  return $new_folders;
}

function savetoftp_process_html($everything, $links, $anon) {
  $node_id = check_plain(arg(1));
  if (is_numeric($node_id)) {
    $node = node_load($node_id);
  }
  $html_name_array = explode("/", $node->path);
  $html_name = end($html_name_array); 
  $html_name = check_plain(str_replace(" ", "", $html_name));
  $html_headers = array(); 
  if (!$anon) {
    $cookie_headers = $_COOKIE;
    foreach ($cookie_headers as $key => $value) {
      $html_headers['Cookie'] = $html_headers['Cookie'] . $key . '=' . $value . '; ';
    }
  }
    if (variable_get('clean_url', NULL)) {
      $stage_site = 'http://'. $_SERVER[HTTP_HOST] . base_path() .'node/'. $node_id;
    }
    else {
      $stage_site = 'http://'. $_SERVER[HTTP_HOST] . base_path() .'?q=node/'. $node_id;
    }
  if ($anon) {
    global $user;
    $current_user = $user;
    session_save_session(FALSE);
    $user = user_load(array('uid' => 0));
    $html_piece = drupal_http_request($stage_site, $html_headers);
    if (!$html_piece->data) {
      drupal_set_message(t('There was a problem getting the Drupal page html'));
    }
    $html_fixed = $html_piece->data;
    $user = $current_user;
    session_save_session(TRUE);
    if (drupal_get_path('module', 'querypath')) {
      $query_path_body = qp($html_piece->data, 'html');
      qp($query_path_body, '.block-user')->html('');
      $html_fixed = $query_path_body->html();
    }
  }
  else {
    $html_piece = drupal_http_request($stage_site, $html_headers);
    if (!$html_piece->data) {
      drupal_set_message(t('There was a problem getting the Drupal page html'));
    }      
    $html_fixed = $html_piece->data;
  }
  if ($everything) {
    $base_path_esc = str_replace('/', '\/', base_path());
    $pattern_css = '/media=\"all\" href=\"'. $base_path_esc .'/';
    $new_pattern_css = 'media="all" href="./';
    $html_fixed = preg_replace($pattern_css, $new_pattern_css, $html_fixed);
    $pattern_js_and_images = '/src=\"'. $base_path_esc .'/';
    $new_pattern_js_and_images = 'src="./';
    $html_fixed = preg_replace($pattern_js_and_images, $new_pattern_js_and_images, $html_fixed);
  }
  elseif ($links) {
    $name = 'http://'. $_SERVER['SERVER_NAME'];
    $pattern_css = '/media=\"all\" href=\"/';
    $new_pattern_css = 'media="all" href="'. $name;
    $html_fixed = preg_replace($pattern_css, $new_pattern_css, $html_fixed);
    $pattern_js_and_images = '/src=\"/';
    $new_pattern_js_and_images = 'src="'. $name;
    $html_fixed = preg_replace($pattern_js_and_images, $new_pattern_js_and_images, $html_fixed);    
  }
  $file_place = file_directory_path() . '/savetoftp/'. $html_name;
  $file = fopen($file_place, "w");
  if (!fwrite($file, $html_fixed)) {
    drupal_set_message(t('Unable to save the html file locally at' . check_plain($file_place) . 'Check your files settings.'));
  }  
  fclose($file);
  return $file_place; // return location of where we save the file
}

function savetoftp_ftp_connect($form_state) {
  $ftp_server = check_plain($form_state['values']['ftp_server']);
  $ftp_uname = check_plain($form_state['values']['ftp_user']);
  $ftp_pass = check_plain($form_state['values']['ftp_pass']);
  $ftp_directory = check_plain($form_state['values']['ftp_direct']);
  $ftp_directory_array = explode('/', $ftp_directory);
  if (!$fp = ftp_connect($ftp_server, 21, 30)) {
    drupal_set_message('Connection failed. Check to make sure the FTP server name is correct');
    return;
  }
  if (!ftp_login($fp, $ftp_uname, $ftp_pass)) {
    drupal_set_message('Login failed. Check your username and password and try again.');
    return;
  }
  if (!ftp_pasv($fp, TRUE)) {
    drupal_set_message(t('Unable to set mode to passive'));
  }
  if ($form_state['values']['ftp_server'] == 'www.sfsu.edu') {
    if (!@ftp_chdir($fp, 'public_html')) {
      drupal_set_message('Unable to change directory to public_html');
    }
  }
  $origin = ftp_pwd($fp);
  //drupal_set_message('Current Directory is: ' . $origin);
  foreach ($ftp_directory_array as $fd) {
    if (!empty($fd)) {
      if (!@ftp_chdir($fp, $fd)) {
        if (!@ftp_mkdir($fp, $fd)) {
          drupal_set_message('Unable to make directory: '. $fd .' Try changing the directory path to something else.');
        }
        if (!@ftp_chdir($fp, $fd)) {
          drupal_set_message('Unable to change directory to: '. $fd .'Are you sure this directory exisists on the server?');
        }
      }
    }  
  }
  return $fp;
}

function savetoftp_ftp_files($fp, $remote_file, $file_place, $everything) {
  set_time_limit(0);
  $path = realpath(file_directory_path() .'/'. 'savetoftp');
  if ($everything) {
    savetoftp_ftp_recurse($fp, $path);
  }
  else {
    if (!ftp_put($fp, $remote_file, $file_place, FTP_BINARY)) {
      drupal_set_message(t('Was unable to put the '. $remote_file .' on the server.'));
    }    
  }
}

function savetoftp_ftp_recurse($fp, $path) {  
  $origin = ftp_pwd($fp);
  $it = new RecursiveIteratorIterator(new RecursiveDirectoryIterator($path));
  while ($it->valid()) {
    if (!$it->isDot()) {  
      $subpath = $it->getSubPath();
      if (!@ftp_chdir($fp, $subpath)) {
        $dir_slashes = str_replace('\\', '/', $subpath);
        $dirs = explode('/', $dir_slashes);
        foreach ($dirs as $dir) {
          if (!@ftp_mkdir($fp, $dir)) {
            //drupal_set_message(t('Was unable to make the '. $dir .' directory'));
          }
          if (!@ftp_chdir($fp, $dir)) {
            //drupal_set_message(t('Was unable to change into the '. $dir .' directory we just made'));
          }
        }
      }
      if ($it->isFile()) {
        $file_to_open = $it->key();
        $remote_file = $it->getFilename();
        if (!ftp_put($fp, $remote_file, $file_to_open, FTP_BINARY)) {
          drupal_set_message(t('Was unable to put the '. $remote_file .' on the server.'));
        }
      }            
    }
    ftp_chdir($fp, $origin);
    $it->next();
  }
}    
