<?php 

/**
  * @file
  * Creates forms for the SavetoFTP module
  * Returns an administration form, a form for uploading files to ftp, and a form for deleting files from ftp
  */

/**
 * An implementation of Form API form form() function.
 * Returns a form where user can enter FTP login credentials and upload a file.
 */

function _savetoftp_form() {
  $node_id = arg(1);
  if (is_numeric($node_id)) {
    $node = node_load($node_id);
  }
  if (isset($node->path)) {
    $save_to_ftp_path = '/'. dirname($node->path);
  }
  $form['header'] = array(
    '#value' => t('<h2>FTP Server Settings for saving a file to the FTP server</h2><strong>You must save any changes FIRST before publishing to the FTP server or your changes might be lost.</strong>'),
  );
  $form['ftp_server'] = array(
    '#type' => 'textfield',
    '#default_value' => check_plain(variable_get('ftp_server', '')),
    '#maxlength' => 50,
    '#size' => 25,    
    '#title' => t('FTP Server'),
    '#prefix' => '<div style="float:left;">',
    '#suffix' => '</div>',    
  );
  $form['ftp_user'] = array(
    '#type' => 'textfield',
    '#default_value' => check_plain(variable_get('ftp_username', '')),
    '#maxlength' => 50,
    '#size' => 15,    
    '#title' => t('FTP Username'),
    '#prefix' => '<div style="float:left;">',
    '#suffix' => '</div>',        
  );
  $form['ftp_pass'] = array(
    '#type' => 'password',
    '#default_value' => check_plain(variable_get('ftp_password', '')),
    '#maxlength' => 50,
    '#size' => 15,
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('FTP Password'),
    '#prefix' => '<div style="float:left;">',
    '#suffix' => '</div>',        
  );
  $form['ftp_direct'] = array(
    '#type' => 'textfield',
    '#default_value' => check_plain(variable_get('ftp_directory', $save_to_ftp_path)),
    '#maxlength' => 50,
    '#size' => 25,    
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('FTP Directory'),
    '#prefix' => '<div>',
    '#suffix' => '</div><div style="clear:both;"></div>',        
    );
  $form['ftp_markup'] = array(
    '#value' => t('<p><strong>FTP Directory is Optional:</strong> By default this is taken from the URL Path. To put your html file in a specific directory on the FTP server, put the full directory here without a trailing slash, e.g., my/files/ or public_html/home, etc.</p>'),
  );  
  $form['ftp_all'] = array(
    '#type' => 'checkbox',
    '#default_value' => check_plain(variable_get('ftp_all', 1)),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('Copy all images, javascript, and css to the ftp server'),
    '#description' => t('<strong>Warning, this will take a long time, up to 90 seconds. If your server is unable to handle the length of time it takes to copy all the files via FTP, then you may receive a timeout</strong>. In addition, this will change the links to your css, js, and images to point to the new location.'),
  );
  $form['ftp_links'] = array(
    '#type' => 'checkbox',
    '#default_value' => check_plain(variable_get('ftp_links', 0)),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('Change the css, js, and image references to be the full link to this server.'),
    '#description' => t('Select this option if you have are running Drupal on a server that is publicly accessible. This way, the file you put on your FTP Server will link to the js, css, and images on this server.)'),
  );
  $form['ftp_anon'] = array(
    '#type' => 'checkbox',
    '#default_value' => check_plain(variable_get('ftp_anon', 0)),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('Retrieve the page as an anonymous user.'),
    '#description' => t('Select this option if you want to get the page as an anonymous user would see it as opposed to how you would see it.)'),
  );  
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Publish to FTP'),
  );
  $form['cancel'] = array(
    '#type' => 'markup',
    '#value' => '<button type="button" onclick="document.getElementById(\'ftp1\').style.display = \'none\'">Cancel</button>',
  );
  return $form;
}

/**
 * An implementation of Form API form form() function.
 * Returns a form where user can enter FTP login credentials and delete a file.
 */
 
function _deleteftp_form() {
  $form['#prefix'] = t('<h2>FTP Server Settings for deleting a file from the FTP server</h2>');
  $form['ftp_server1'] = array(
    '#type' => 'textfield',
    '#default_value' => check_plain(variable_get('ftp_server1', '')),
    '#maxlength' => 50,
    '#title' => t('FTP Server'),
    );
  $form['ftp_user1'] = array(
    '#type' => 'textfield',
    '#default_value' => check_plain(variable_get('ftp_username1', '')),
    '#maxlength' => 50,
    '#size' => 25,    
    '#title' => t('FTP Username'),
    );
  $form['ftp_pass1'] = array(
    '#type' => 'password',
    '#default_value' => check_plain(variable_get('ftp_password1', '')),
    '#maxlength' => 50,
    '#size' => 15,
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('FTP Password'),
    );
  $form['ftp_direct1'] = array(
    '#type' => 'textfield',
    '#default_value' => check_plain(variable_get('ftp_directory1', '')),
    '#maxlength' => 50,
    '#size' => 25,
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => 'FTP Directory',
    '#description' => t('Enter your default directory, this will most likely be public_html or blank'),
    );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Delete file from FTP'),
  );
  $form['cancel'] = array(
    '#type' => 'markup',
    '#value' => '<button type="button" onclick="document.getElementById(\'ftp2\').style.display = \'none\'">Cancel</button>',
  );
  return $form;
}